{% extends "bi/base.html" %}

{% block content %}

    {% if form.errors %}
        <p>Нет пользователя с таким именем пользователя и паролем.</p>
    {% endif %}

    {% if next %}
        {% if user.is_authenticated %}
            <p>
                Ваш пользователь не имеет прав на просмотр этой страницы.
                Чтобы продолжить, войдите под пользователем, у которого есть соответствующие права.
            </p>
        {% else %}
            <p>Пожалуйста, залогиньтесь, чтобы увидеть эту страницу.</p>
        {% endif %}
    {% endif %}

    <div class="login-box">
        <div class="login-logo">
            <a href="/"><b>DB</b>LRA</a>
        </div>
        <div class="login-box-body">
            <p class="login-box-msg">Sign in to start your session</p>

            <form action="{% url 'login' %}" method="post">
                {% csrf_token %}
                <div class="form-group has-feedback">
                    <input id="id_username" name="username" placeholder="Username" class="form-control">
                    <span class="glyphicon glyphicon-user form-control-feedback"></span>
                </div>
                <div class="form-group has-feedback">
                    <input type="password" id="id_password" name="password" placeholder="Password" class="form-control">
                    <span class="glyphicon glyphicon-lock form-control-feedback"></span>
                </div>
                <div class="row">
                    <div class="col-xs-8"></div>
                    <div class="col-xs-4">
                        <button type="submit" class="btn btn-primary btn-block btn-flat">Sign In</button>
                        <input type="hidden" name="next" value="{{ next }}">
                    </div>
                </div>
            </form>
        </div>
    </div>

{% endblock %}
